==> nifi-1.28.1-source-release.zip: nifi-1.28.1/nifi-commons/nifi-write-ahead-log/src/main/java/org/apache/nifi/wali/SnapshotRecovery.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.nifi.wali;

import java.io.File;
import java.util.Collections;
import java.util.Map;
import java.util.Set;

public interface SnapshotRecovery<T> {
    long getMaxTransactionId();

    Map<Object, T> getRecords();

    Set<String> getRecoveredSwapLocations();

    File getRecoveryFile();


    public static <T> SnapshotRecovery<T> emptyRecovery() {
        return new SnapshotRecovery<T>() {
            @Override
            public long getMaxTransactionId() {
                return -1L;
            }

            @Override
            public Map<Object, T> getRecords() {
                return Collections.emptyMap();
            }

            @Override
            public Set<String> getRecoveredSwapLocations() {
                return Collections.emptySet();
            }

            @Override
            public File getRecoveryFile() {
                return null;
            }
        };
    }
}

==> nifi-2.6.0-source-release.zip: nifi-2.6.0/nifi-commons/nifi-write-ahead-log/src/main/java/org/apache/nifi/wali/SnapshotRecovery.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.nifi.wali;

import java.io.File;
import java.util.Collections;
import java.util.Map;
import java.util.Set;

public interface SnapshotRecovery<T> {
    long getMaxTransactionId();

    Map<Object, T> getRecords();

    Set<String> getRecoveredSwapLocations();

    File getRecoveryFile();


    static <T> SnapshotRecovery<T> emptyRecovery() {
        return new SnapshotRecovery<>() {
            @Override
            public long getMaxTransactionId() {
                return -1L;
            }

            @Override
            public Map<Object, T> getRecords() {
                return Collections.emptyMap();
            }

            @Override
            public Set<String> getRecoveredSwapLocations() {
                return Collections.emptySet();
            }

            @Override
            public File getRecoveryFile() {
                return null;
            }
        };
    }
}
